%filter_provides_in %{python_sitearch}/.*\.so$ 
%filter_setup

Name:               s3ql
Version:            1.13.2
Release:            1%{?dist}
Summary:            Full-Featured File System for Online Data Storage
Source0:            http://s3ql.googlecode.com/files/%{name}-%{version}.tar.bz2
URL:                http://code.google.com/p/s3ql/
Group:              System Environment/Base
License:            GPLv3

BuildRequires:      python-setuptools
BuildRequires:      pycryptopp
BuildRequires:      python-apsw >= 3.7.0
BuildRequires:      python-llfuse >= 0.37
BuildRequires:      pyliblzma
BuildRequires:      python-sphinx
BuildRequires:      Cython
BuildRequires:      python2-devel
BuildRequires:      sqlite-devel
BuildRequires:      python-unittest2
BuildRequires:      pytest

Requires:           pyliblzma
Requires:           pycryptopp
Requires:           python-apsw >= 3.7.0
Requires:           python-llfuse >= 0.37
Requires:           python-setuptools


%description
S3QL is a file system that stores all its data online using storage services
like Google Storage, Amazon S3 or OpenStack. S3QL effectively provides a hard
disk of dynamic, infinite capacity that can be accessed from any computer
with Internet access.

S3QL is a standard conforming, full featured UNIX file system that is
conceptually indistinguishable from any local file system. Furthermore, S3QL
has additional features like compression, encryption, data de-duplication,
immutable trees and snapshotting which make it especially suitable for on-line
backup and archival.

S3QL is designed to favor simplicity and elegance over performance and feature-
creep. Care has been taken to make the source code as readable and serviceable
as possible. Solid error detection and error handling have been included
from the very first line, and S3QL comes with extensive automated test cases
for all its components.

%prep
%setup -q
rm -rf doc/html/man
rm doc/html/.buildinfo
rm -rf src/%{name}.egg-info


%build
PYTHONDONTWRITEBYTECODE= %__python ./setup.py build

%check
# we can't test those, they use fuse and require the fuse
# kernel module to be loaded, which we cannot do from a
# chrooted package build environment where we don't run
# as root:
rm tests/t4* tests/t5*
%__python ./setup.py test

%install
%__python ./setup.py install \
    --prefix="%{_prefix}" \
    --root="%{buildroot}"

for x in contrib/*.py; do
    f="${x##*/}"
    case $f in
        *dummy*) continue ;;
        %{name}*) t="$f" ;;
        *) t="%{name}-$f" ;;
    esac
    t="${t%.py}"
    install -D -m0755 "$x" "%{buildroot}%{_bindir}/$t"
done
install -D -m0755 contrib/s3ql_backup.sh "%{buildroot}%{_bindir}/s3ql_backup"

find "%{buildroot}%{python_sitearch}" -type f -name '*.py' -exec %__chmod 0644 {} \;
# remove shebangs
find "%{buildroot}%{python_sitearch}" -type f -name '*.py' -exec %__sed -i -e '/^#!\//, 1d' {} \;
# recompile to fix mtimes
%__python -c 'import compileall; compileall.compile_dir("%{buildroot}%{python_sitearch}/",ddir="%{python_sitearch}/",force=True)'

%__perl -p -i -e 's,^(%{_mandir}/man\d/.+\.\d),${1}%{ext_man},' files.lst



%files
%doc doc/html
%doc Changes.txt LICENSE
%{_bindir}/*
%{_mandir}/man1/*
%{python_sitearch}/%{name}*


%changelog
* Mon Mar 04 2013 Marcel Wysocki <maci@satgnu.net> - 1.13.2-1
- updated to version 1.13.2
- add pytest BR
- fixes BZ#914501

* Fri Feb 15 2013 Marcel Wysocki <maci@satgnu.net> - 1.12-9
- rebuilt

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.12-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Nov 02 2012 Marcel Wysocki <maci@satgnu.net> 1.12-7
- python-argparse is provided by python-libs, remove it from requires

* Fri Nov 02 2012 Marcel Wysocki <maci@satgnu.net> 1.12-6
- fixed ownership /usr/lib*/python*/site-packages/s3ql*
- added LICENSE

* Fri Nov 02 2012 Marcel Wysocki <maci@satgnu.net> 1.12-5
- filter out private shared objects
- replace tabs by spaces
- clean up requires and buildrequires
- remove egg-info

* Thu Nov 01 2012 Marcel Wysocki <maci@satgnu.net> 1.12-4
- use python-setuptools instead of python-distribute
- add pyliblzma to BR

* Wed Oct 31 2012 Marcel Wysocki <maci@satgnu.net> 1.12-3
- remove python from deps, rpm knows it
- use python2-devel in BR

* Tue Oct 23 2012 Marcel Wysocki <maci@satgnu.net> 1.12-2
- don't use rm and install macros
- add missing dependencies

* Thu Oct 04 2012 Marcel Wysocki <maci@satgnu.net> 1.12-1
- update to 1.12
- fedora port
- fixed dependencies

* Sat May 05 2012 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.11.1-1
+ Revision: 796590
- update ti 1.11.1

* Sat Feb 25 2012 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.10-1
+ Revision: 780718
- new version 1.10

* Sun Jan 22 2012 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.9-1
+ Revision: 764917
- new version 1.9

* Tue Dec 06 2011 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.8.1-1
+ Revision: 738422
- Update to 1.8.1

* Wed Nov 30 2011 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.7-2
+ Revision: 735709
- release bump
- requires fixed
- BR fixed

* Tue Nov 29 2011 Dmitry Mikhirev <dmikhirev@mandriva.org> 1.7-1
+ Revision: 735440
- create package
- create current

